netapp_ontap.models.application_nvme_access API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.application_nvme_access`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ApplicationNvmeAccessSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ApplicationNvmeAccess object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `backing_storage: ApplicationNvmeAccessBackingStorage GET`

    The backing_storage field of the application_nvme_access.

  `is_clone: bool GET`

    Clone

  `subsystem_map: ApplicationSubsystemMapObject GET POST PATCH`

    Subsystem map object